==> cyanlib-1.0.4%2B1.19.4-sources.jar: fr/aeldit/cyanlib/lib/gui/CyanLibConfigScreen.java <==
package fr.aeldit.cyanlib.lib.gui;

import fr.aeldit.cyanlib.lib.config.CyanLibOptionsStorage;
import fr.aeldit.cyanlib.lib.config.ICyanLibConfig;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_353;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_4587;
import net.minecraft.class_4667;
import net.minecraft.class_5244;
import net.minecraft.class_7919;
import java.util.Objects;

import static fr.aeldit.cyanlib.lib.CyanLib.CONFIG_CLASS_INSTANCES;

@Environment(EnvType.CLIENT)
public class CyanLibConfigScreen extends class_4667
{
    private final CyanLibOptionsStorage cyanLibOptionsStorage;
    private final class_437 parent;
    private final ICyanLibConfig configOptionsClass;
    private class_353 optionList;

    public CyanLibConfigScreen(class_437 previous, class_437 parent, String modid)
    {
        super(previous, class_310.method_1551().field_1690,
              class_2561.method_43471("%s.screen.options.title".formatted(modid))
        );
        this.field_21335 = parent;
        this.cyanLibOptionsStorage = CONFIG_CLASS_INSTANCES.get(modid).getOptionsStorage();
        this.configOptionsClass = this.cyanLibOptionsStorage.getConfigClass();
    }

    @Override
    public void method_25419()
    {
        cyanLibOptionsStorage.writeConfig();
        Objects.requireNonNull(field_22787).method_1507(field_21335);
    }

    //? if =1.19.4 {
    @Override
    public void method_25394(class_4587 matrices, int mouseX, int mouseY, float delta)
    {
        this.method_25434(matrices);
        optionList.method_25394(matrices, mouseX, mouseY, delta);
        method_27534(matrices, this.field_22793, this.field_22785, this.field_22789 / 2, 5, 0xffffff);
        super.method_25394(matrices, mouseX, mouseY, delta);
    }
    //?} elif =1.20.1 {
    /*@Override
    public void render(DrawContext context, int mouseX, int mouseY, float delta)
    {
        optionList.render(context, mouseX, mouseY, delta);
        context.drawCenteredTextWithShadow(textRenderer, title, width / 2, 5, 0xffffff);
        super.render(context, mouseX, mouseY, delta);
    }
    *///?} else {
    /*@Override
    public void render(DrawContext context, int mouseX, int mouseY, float delta)
    {
        super.render(context, mouseX, mouseY, delta);
        optionList.render(context, mouseX, mouseY, delta);
        context.drawCenteredTextWithShadow(textRenderer, title, width / 2, 5, 0xffffff);
    }
    *///?}

    //? if =1.20.2 {
    /*@Override
    public void renderBackground(DrawContext context, int mouseX, int mouseY, float delta)
    {
        super.renderBackgroundTexture(context);
    }
    *///?}

    @Override
    protected void method_25426()
    {
        //? if >=1.21-1.21.1 {
        /*optionList = new OptionListWidget(client, width, this);
        *///?} elif =1.20.6 {
        /*optionList = new OptionListWidget(client, width, height, this);
         *///?} elif =1.20.4 {
        /*optionList = new OptionListWidget(client, width, height - 66, 32, 32);
         *///?} elif =1.20.2 || =1.20.1 {
        /*optionList = new OptionListWidget(client, width, height, 32, height - 32, 32);
         *///?} elif =1.19.4 {
        optionList = new class_353(field_22787, field_22789, field_22790, 32, field_22790 - 32, 25);
         //?}
        optionList.method_20408(CyanLibOptionsStorage.asConfigOptions(configOptionsClass));
        method_25429(optionList);

        method_37063(
                class_4185.method_46430(class_2561.method_43471("cyanlib.screen.config.reset"), button -> {
                                cyanLibOptionsStorage.resetOptions();
                                method_25419();
                            })
                            .method_46436(class_7919.method_47407(class_2561.method_43471("cyanlib.screen.config.reset.tooltip")))
                            .method_46434(10, 6, 100, 20)
                            .method_46431()
        );

        method_37063(
                class_4185.method_46430(class_5244.field_24334, button -> method_25419())
                            .method_46434(field_22789 / 2 - 100, field_22790 - 28, 200, 20)
                            .method_46431()
        );
    }

    //? if >=1.21-1.21.1 {
    /*@Override
    protected void addOptions()
    {
    }
    *///?}
}

==> cyanlib-1.0.6%2B1.21.2-1.21.3-sources.jar: fr/aeldit/cyanlib/lib/gui/CyanLibConfigScreen.java <==
package fr.aeldit.cyanlib.lib.gui;

import fr.aeldit.cyanlib.lib.config.CyanLibOptionsStorage;
import fr.aeldit.cyanlib.lib.config.ICyanLibConfig;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_353;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_4667;
import net.minecraft.class_5244;
import net.minecraft.class_7919;
import java.util.Objects;

import static fr.aeldit.cyanlib.lib.CyanLib.CONFIG_CLASS_INSTANCES;

@Environment(EnvType.CLIENT)
public class CyanLibConfigScreen extends class_4667
{
    private final CyanLibOptionsStorage cyanLibOptionsStorage;
    private final class_437 parent;
    private final ICyanLibConfig configOptionsClass;
    private class_353 optionList;

    public CyanLibConfigScreen(class_437 previous, class_437 parent, String modid)
    {
        super(previous, class_310.method_1551().field_1690,
              class_2561.method_43471("%s.screen.options.title".formatted(modid))
        );
        this.field_21335 = parent;
        this.cyanLibOptionsStorage = CONFIG_CLASS_INSTANCES.get(modid).getOptionsStorage();
        this.configOptionsClass = this.cyanLibOptionsStorage.getConfigClass();
    }

    @Override
    public void method_25419()
    {
        cyanLibOptionsStorage.writeConfig();
        Objects.requireNonNull(field_22787).method_1507(field_21335);
    }

    //? if =1.19.4 {
    /*@Override
    public void render(MatrixStack matrices, int mouseX, int mouseY, float delta)
    {
        this.renderBackgroundTexture(matrices);
        optionList.render(matrices, mouseX, mouseY, delta);
        drawCenteredTextWithShadow(matrices, this.textRenderer, this.title, this.width / 2, 5, 0xffffff);
        super.render(matrices, mouseX, mouseY, delta);
    }
    *///?} elif =1.20.1 {
    /*@Override
    public void render(DrawContext context, int mouseX, int mouseY, float delta)
    {
        optionList.render(context, mouseX, mouseY, delta);
        context.drawCenteredTextWithShadow(textRenderer, title, width / 2, 5, 0xffffff);
        super.render(context, mouseX, mouseY, delta);
    }
    *///?} else {
    @Override
    public void method_25394(class_332 context, int mouseX, int mouseY, float delta)
    {
        super.method_25394(context, mouseX, mouseY, delta);
        optionList.method_25394(context, mouseX, mouseY, delta);
        context.method_27534(field_22793, field_22785, field_22789 / 2, 5, 0xffffff);
    }
    //?}

    //? if =1.20.2 {
    /*@Override
    public void renderBackground(DrawContext context, int mouseX, int mouseY, float delta)
    {
        super.renderBackgroundTexture(context);
    }
    *///?}

    @Override
    protected void method_25426()
    {
        //? if >=1.21-1.21.1 {
        optionList = new class_353(field_22787, field_22789, this);
        //?} elif =1.20.6 {
        /*optionList = new OptionListWidget(client, width, height, this);
         *///?} elif =1.20.4 {
        /*optionList = new OptionListWidget(client, width, height - 66, 32, 32);
         *///?} elif =1.20.2 || =1.20.1 {
        /*optionList = new OptionListWidget(client, width, height, 32, height - 32, 32);
         *///?} elif =1.19.4 {
        /*optionList = new OptionListWidget(client, width, height, 32, height - 32, 25);
         *///?}
        optionList.method_20408(CyanLibOptionsStorage.asConfigOptions(configOptionsClass));
        method_25429(optionList);

        method_37063(
                class_4185.method_46430(class_2561.method_43471("cyanlib.screen.config.reset"), button -> {
                                cyanLibOptionsStorage.resetOptions();
                                method_25419();
                            })
                            .method_46436(class_7919.method_47407(class_2561.method_43471("cyanlib.screen.config.reset.tooltip")))
                            .method_46434(10, 6, 100, 20)
                            .method_46431()
        );

        method_37063(
                class_4185.method_46430(class_5244.field_24334, button -> method_25419())
                            .method_46434(field_22789 / 2 - 100, field_22790 - 28, 200, 20)
                            .method_46431()
        );
    }

    //? if >=1.21-1.21.1 {
    @Override
    protected void method_60325()
    {
    }
    //?}
}
